@@ -1,5 +1,7 @@
+import logging
 from timestream.dimensions import TimestreamDimensions
 from timestream.record import TimestreamRecord
+from timestream import DEFAULT_LOGGER
 from typing import List, Tuple
 
 DEFAULT_MAX_BATCH_SIZE = 100 # maximum set by AWS Timestream service limits
@@ -14,15 +16,19 @@ class Batch:
     ):
         self.records = records or []
         self.common_dimensions = common_dimensions or TimestreamDimensions()
+        
 
 
 def batch_records(
     records: List[TimestreamRecord],
     max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-    min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
+    min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
+    logger: logging.Logger = DEFAULT_LOGGER
 ) -> List[Batch]:
     batches, remaining = [], records
+    logger.info(f"MAX BATCH || {max_batch_size}  MIN COMMON DIM || {min_common_dimensions}")
     while len(remaining) > 0:
+        logger.info(remaining)
         batch, remaining = _batch_records_helper(
             remaining, max_batch_size, min_common_dimensions
         )
